@@ -14,8 +14,9 @@ use English qw/ -no_match_vars /;
 use IO::Prompt qw/prompt/;
 use JSON qw/decode_json/;
 use WWW::Mechanize;
+use Path::Class;
 
-our $VERSION     = version->new('0.1.4');
+our $VERSION     = version->new('0.1.5');
 
 extends 'Group::Git';
 
@@ -44,7 +45,7 @@ sub _repos {
     my $repos = decode_json $mech->content;
     for my $repo ( @$repos ) {
         $repos{$repo->{name}} = Group::Git::Repo->new(
-            name => $repo->{name},
+            name => dir($repo->{name}),
             url  => "https://bitbucket.org/$repo->{owner}/$repo->{name}",
             git  => "git\@bitbucket.org:$repo->{owner}/$repo->{name}.git",
         );
@@ -63,7 +64,7 @@ Group::Git::Bitbucket - Adds reading all repositories you have access to on bitb
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Bitbucket version 0.1.4.
+This documentation refers to Group::Git::Bitbucket version 0.1.5.
 
 =head1 SYNOPSIS
 
