@@ -12,8 +12,9 @@ use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Net::GitHub;
+use Path::Class;
 
-our $VERSION     = version->new('0.1.4');
+our $VERSION     = version->new('0.1.5');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 #our @EXPORT      = qw//;
@@ -39,7 +40,7 @@ sub _repos {
     while (@list) {
         for my $repo (@list) {
             $repos{ $repo->{name} } = Group::Git::Repo->new(
-                name => $repo->{name},
+                name => dir($repo->{name}),
                 git  => $repo->{git_url},
             );
         }
@@ -73,7 +74,7 @@ Group::Git::Github - Adds reading all repositories you have access to on github
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Github version 0.1.4.
+This documentation refers to Group::Git::Github version 0.1.5.
 
 
 =head1 SYNOPSIS
