@@ -13,8 +13,9 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Path::Class;
 use File::chdir;
+use Path::Class;
 
-our $VERSION     = version->new('0.1.4');
+our $VERSION     = version->new('0.1.5');
 
 extends 'Group::Git';
 
@@ -55,7 +56,7 @@ sub _repos {
 
                 for my $name ( split /\s+/, $data->{$group}{$sub_group}{$type} ) {
                     $repos{$name} = Group::Git::Repo->new(
-                        name => $name,
+                        name => dir($name),
                         git  => "$base$name.git",
                     );
                 }
@@ -76,7 +77,7 @@ Group::Git::Gitosis - <One-line description of module's purpose>
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Gitosis version 0.1.4.
+This documentation refers to Group::Git::Gitosis version 0.1.5.
 
 
 =head1 SYNOPSIS
